@@ -1,18 +1,16 @@
 import argparse
-import shlex
 import subprocess
-from subprocess import check_call, check_output, call
-import re
-import luxem
-import os.path
+from subprocess import check_call, check_output
 import json
+import os.path
 import logging
 from pathlib import Path
-from tempfile import NamedTemporaryFile
 import abc
 from functools import wraps
 import sys
 
+import luxem
+
 
 here = Path(__file__).parent
 
@@ -148,7 +146,6 @@ class APTPlugin(Plugin):
             else:
                 if name in self._ignore():
                     logging.debug(f"Package {name} is part of the base system.")
-                    continue
                 default.append(name)
         if default:
             sudo().cc(["apt-get", "install", "-y"] + default)
